package com.ynet.life.log;

import java.io.File;
import java.io.IOException;
import java.io.Writer;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;
import java.util.TimeZone;
import org.apache.log4j.FileAppender;
import org.apache.log4j.Layout;
import org.apache.log4j.helpers.CountingQuietWriter;
import org.apache.log4j.helpers.LogLog;
import org.apache.log4j.helpers.OptionConverter;
import org.apache.log4j.spi.LoggingEvent;

/* loaded from: com_ynet_life_log.jar:com/ynet/life/log/DailyRollingBySizeFileAppender.class */
public class DailyRollingBySizeFileAppender extends FileAppender {
    static final int TOP_OF_TROUBLE = -1;
    static final int TOP_OF_MINUTE = 0;
    static final int TOP_OF_HOUR = 1;
    static final int HALF_DAY = 2;
    static final int TOP_OF_DAY = 3;
    static final int TOP_OF_WEEK = 4;
    static final int TOP_OF_MONTH = 5;
    protected int maxBackupIndex;
    protected long maxFileSize;
    private String datePattern;
    private String scheduledFilename;
    private long nextCheck;
    Date now;
    SimpleDateFormat sdf;
    LianaRollingCalendar rc;
    int checkPeriod;
    static final TimeZone gmtTimeZone = TimeZone.getTimeZone("GMT");

    public void setMaxBackupIndex(int maxBackups) {
        this.maxBackupIndex = maxBackups;
    }

    public int getMaxBackupIndex() {
        return this.maxBackupIndex;
    }

    public long getMaximumFileSize() {
        return this.maxFileSize;
    }

    public void setMaximumFileSize(long maxFileSize) {
        this.maxFileSize = maxFileSize;
    }

    public void setMaxFileSize(String value) {
        this.maxFileSize = OptionConverter.toFileSize(value, this.maxFileSize + 1);
    }

    protected void setQWForFiles(Writer writer) {
        this.qw = new CountingQuietWriter(writer, this.errorHandler);
    }

    public DailyRollingBySizeFileAppender() {
        this.maxBackupIndex = 40;
        this.maxFileSize = 524288000L;
        this.datePattern = "'.'yyyy-MM-dd";
        this.nextCheck = System.currentTimeMillis() - 1;
        this.now = new Date();
        this.rc = new LianaRollingCalendar();
        this.checkPeriod = TOP_OF_TROUBLE;
    }

    public DailyRollingBySizeFileAppender(Layout layout, String filename, String datePattern) throws IOException {
        super(layout, filename, true);
        this.maxBackupIndex = 40;
        this.maxFileSize = 524288000L;
        this.datePattern = "'.'yyyy-MM-dd";
        this.nextCheck = System.currentTimeMillis() - 1;
        this.now = new Date();
        this.rc = new LianaRollingCalendar();
        this.checkPeriod = TOP_OF_TROUBLE;
        this.datePattern = datePattern;
        activateOptions();
    }

    public void setDatePattern(String pattern) {
        this.datePattern = pattern;
    }

    public String getDatePattern() {
        return this.datePattern;
    }

    public void activateOptions() {
        super.activateOptions();
        if (this.datePattern != null && this.fileName != null) {
            this.now.setTime(System.currentTimeMillis());
            this.sdf = new SimpleDateFormat(this.datePattern);
            int type = computeCheckPeriod();
            printPeriodicity(type);
            this.rc.setType(type);
            File file = new File(this.fileName);
            this.scheduledFilename = String.valueOf(this.fileName) + this.sdf.format(new Date(file.lastModified()));
            return;
        }
        LogLog.error("Either File or DatePattern options are not set for appender [" + this.name + "].");
    }

    void printPeriodicity(int type) {
        switch (type) {
            case TOP_OF_MINUTE /* 0 */:
                LogLog.debug("Appender [" + this.name + "] to be rolled every minute.");
                return;
            case TOP_OF_HOUR /* 1 */:
                LogLog.debug("Appender [" + this.name + "] to be rolled on top of every hour.");
                return;
            case HALF_DAY /* 2 */:
                LogLog.debug("Appender [" + this.name + "] to be rolled at midday and midnight.");
                return;
            case TOP_OF_DAY /* 3 */:
                LogLog.debug("Appender [" + this.name + "] to be rolled at midnight.");
                return;
            case TOP_OF_WEEK /* 4 */:
                LogLog.debug("Appender [" + this.name + "] to be rolled at start of week.");
                return;
            case TOP_OF_MONTH /* 5 */:
                LogLog.debug("Appender [" + this.name + "] to be rolled at start of every month.");
                return;
            default:
                LogLog.warn("Unknown periodicity for appender [" + this.name + "].");
                return;
        }
    }

    int computeCheckPeriod() {
        LianaRollingCalendar rollingCalendar = new LianaRollingCalendar(gmtTimeZone, Locale.ENGLISH);
        Date epoch = new Date(0L);
        if (this.datePattern != null) {
            for (int i = TOP_OF_MINUTE; i <= TOP_OF_MONTH; i += TOP_OF_HOUR) {
                SimpleDateFormat simpleDateFormat = new SimpleDateFormat(this.datePattern);
                simpleDateFormat.setTimeZone(gmtTimeZone);
                String r0 = simpleDateFormat.format(epoch);
                rollingCalendar.setType(i);
                Date next = new Date(rollingCalendar.getNextCheckMillis(epoch));
                String r1 = simpleDateFormat.format(next);
                if (r0 != null && r1 != null && !r0.equals(r1)) {
                    return i;
                }
            }
            return TOP_OF_TROUBLE;
        }
        return TOP_OF_TROUBLE;
    }

    void rollOverByDate() throws IOException {
        if (this.datePattern == null) {
            this.errorHandler.error("Missing DatePattern option in rollOver().");
            return;
        }
        String datedFilename = String.valueOf(this.fileName) + this.sdf.format(this.now);
        if (this.scheduledFilename.equals(datedFilename)) {
            return;
        }
        closeFile();
        File target = new File(this.scheduledFilename);
        if (target.exists()) {
            target.delete();
        }
        if (new File(this.fileName).renameTo(target)) {
            LogLog.debug(String.valueOf(this.fileName) + " -> " + this.scheduledFilename);
        } else {
            LogLog.error("Failed to rename [" + this.fileName + "] to [" + this.scheduledFilename + "].");
        }
        try {
            setFile(this.fileName, false, this.bufferedIO, this.bufferSize);
        } catch (IOException unused) {
            this.errorHandler.error("setFile(" + this.fileName + ", false) call failed.");
        }
        this.scheduledFilename = datedFilename;
    }

    private void rollOverBySize() {
        LogLog.debug("rolling over count=" + this.qw.getCount());
        LogLog.debug("maxBackupIndex=" + this.maxBackupIndex);
        if (this.maxBackupIndex > 0) {
            String datedFilename = String.valueOf(this.fileName) + this.sdf.format(this.now);
            File file = new File(String.valueOf(datedFilename) + '.' + this.maxBackupIndex);
            if (file.exists()) {
                file.delete();
            }
            for (int i = this.maxBackupIndex - TOP_OF_HOUR; i > 0; i += TOP_OF_TROUBLE) {
                File file2 = new File(String.valueOf(datedFilename) + '.' + i);
                if (file2.exists()) {
                    File target = new File(String.valueOf(datedFilename) + '.' + (i + TOP_OF_HOUR));
                    LogLog.debug("Renaming file " + file2 + " to " + target);
                    file2.renameTo(target);
                }
            }
            File target2 = new File(String.valueOf(datedFilename) + '.' + TOP_OF_HOUR);
            closeFile();
            File file3 = new File(this.fileName);
            LogLog.debug("Renaming file " + file3 + " to " + target2);
            file3.renameTo(target2);
        }
        try {
            setFile(this.fileName, false, this.bufferedIO, this.bufferSize);
        } catch (IOException e) {
            LogLog.error("setFile(" + this.fileName + ", false) call failed.", e);
        }
    }

    protected void subAppend(LoggingEvent event) {
        long n = System.currentTimeMillis();
        if (n >= this.nextCheck) {
            this.now.setTime(n);
            this.nextCheck = this.rc.getNextCheckMillis(this.now);
            try {
                rollOverByDate();
            } catch (IOException ioe) {
                LogLog.error("rollOver() failed.", ioe);
            }
        }
        super.subAppend(event);
        if (this.fileName != null && this.qw.getCount() >= this.maxFileSize) {
            rollOverBySize();
        }
    }
}
